@@ -35,7 +35,6 @@
 #include <stdio.h>
 #include "jpeglib.h"
 #include "jerror.h"
-
 #include "tiffiop.h"
 
 /*
@@ -138,7 +137,7 @@ void ImgTIFFsetByteArray _ANSI_ARGS_((VOID **, VOID*, long));
 int ImgTIFFSetField _ANSI_ARGS_(TCL_VARARGS(TIFF *, tif));
 tsize_t ImgTIFFTileSize _ANSI_ARGS_((TIFF*));
 
-int Imgjpeg_resync_to_restart _ANSI_ARGS_((j_decompress_ptr, int));
+boolean Imgjpeg_resync_to_restart _ANSI_ARGS_((j_decompress_ptr, int));
 JDIMENSION Imgjpeg_read_scanlines _ANSI_ARGS_((j_decompress_ptr,
 			JSAMPARRAY, JDIMENSION));
 int Imgjpeg_set_colorspace _ANSI_ARGS_((j_compress_ptr, J_COLOR_SPACE));
@@ -766,12 +765,16 @@ JPEGSetupDecode(tif)
  * Set up for decoding a strip or tile.
  */
 
-static int JPEGPreDecode _ANSI_ARGS_((TIFF* tif, tsample_t s));
-
 static int
+#ifdef _USING_PROTOTYPES_
+JPEGPreDecode (
+    TIFF* tif,
+    tsample_t s)
+#else
 JPEGPreDecode(tif, s)
     TIFF* tif;
     tsample_t s;
+#endif
 {
 	JPEGState *sp = JState(tif);
 	TIFFDirectory *td = &tif->tif_dir;
@@ -900,13 +903,20 @@ JPEGPreDecode(tif, s)
  * "Standard" case: returned data is not downsampled.
  */
 
-static int JPEGDecode _ANSI_ARGS_((TIFF*, tidata_t, tsize_t, tsample_t));
 static int
+#ifdef _USING_PROTOTYPES_
+JPEGDecode (
+    TIFF* tif,
+    tidata_t buf,
+    tsize_t cc,
+    tsample_t s)
+#else
 JPEGDecode(tif, buf, cc, s)
     TIFF* tif;
     tidata_t buf;
     tsize_t cc;
     tsample_t s;
+#endif
 {
 	JPEGState *sp = JState(tif);
 	tsize_t nrows;
@@ -938,13 +948,20 @@ JPEGDecode(tif, buf, cc, s)
  * Returned data is downsampled per sampling factors.
  */
 
-static int JPEGDecodeRaw _ANSI_ARGS_((TIFF*, tidata_t, tsize_t, tsample_t));
 static int
+#ifdef _USING_PROTOTYPES_
+JPEGDecodeRaw (
+    TIFF* tif,
+    tidata_t buf,
+    tsize_t cc,
+    tsample_t s)
+#else
 JPEGDecodeRaw(tif, buf, cc, s)
     TIFF* tif;
     tidata_t buf;
     tsize_t cc;
     tsample_t s;
+#endif
 {
 	JPEGState *sp = JState(tif);
 	JSAMPLE* inptr;
@@ -1199,11 +1216,16 @@ JPEGSetupEncode(tif)
  * Set encoding state at the start of a strip or tile.
  */
 
-static int JPEGPreEncode _ANSI_ARGS_((TIFF*, tsample_t));
 static int
+#ifdef _USING_PROTOTYPES_
+JPEGPreEncode (
+    TIFF* tif,
+    tsample_t s)
+#else
 JPEGPreEncode(tif, s)
     TIFF* tif;
     tsample_t s;
+#endif
 {
 	JPEGState *sp = JState(tif);
 	TIFFDirectory *td = &tif->tif_dir;
